@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 3323 2007-12-02 21:52:07Z wwalker $"
-__version__   = "$Revision: 3323 $"
-__date__      = "$Date: 2007-12-02 16:52:07 -0500 (Sun, 02 Dec 2007) $"
+__id__        = "$Id: gnomespeechfactory.py 3985 2008-06-17 19:11:50Z wwalker $"
+__version__   = "$Revision: 3985 $"
+__date__      = "$Date: 2008-06-17 15:11:50 -0400 (Tue, 17 Jun 2008) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -52,6 +52,50 @@ from orca_i18n import _           # for gettext support
 ORBit.load_typelib('GNOME_Speech')
 import GNOME.Speech, GNOME__POA.Speech
 
+def _matchLanguage(desired, actual):
+    """Compares a desired language to an actual language and returns
+    a numerical value representing the degree of match.  The expected
+    language format is a string similar to the following, where the
+    delimiter can be '-' '_' or '.':
+
+      de-DE (German for Germany)
+      en-US (English as used in the United States)
+
+    Additional extensions for variants or dialects are allowed as well.
+
+    The return value is one of the following:
+
+      0 - no match at all
+      1 - some match
+      2 - exact match
+    """
+
+    if desired == actual:
+        return 2
+    if not desired or not actual:
+        return 0
+
+    # Break the strings into arrays where the delimiters are
+    # - or _.  Also lowercase everything to help with string 
+    # compares.
+    #
+    desired = desired.lower().replace("-","_").replace(".","_").split("_")
+    actual = actual.lower().replace("-","_").replace(".","_").split("_")
+
+    matchCount = 0
+    for i in range(0, min(len(desired), len(actual))):
+        if desired[i] == actual[i]:
+            matchCount += 1
+        else:
+            break
+
+    if matchCount == len(desired):
+        return 2
+    elif matchCount:
+        return 1
+    else:
+        return 0
+        
 class _SayAll:
     def __init__(self, iterator, context, utteranceId, progressCallback):
         self.utteranceIterator   = iterator
@@ -411,7 +455,16 @@ class SpeechServer(speechserver.SpeechServer):
         voices = self.__driver.getAllVoices()
         foundVoices = []
         for voice in voices:
-            if voice.language in languages:
+            match = 0
+            for language in languages:
+                match = max(match, _matchLanguage(voice.language, language))
+
+            # Exact matches get put at the beginning, inexact get added to
+            # the end.
+            #
+            if match == 2:
+                foundVoices.insert(0, voice)
+            elif match:
                 foundVoices.append(voice)
 
         # If we didn't find any matches, well...punt.
@@ -453,12 +506,16 @@ class SpeechServer(speechserver.SpeechServer):
 
         speaker = _Speaker(s._narrow(GNOME.Speech.Speaker))
 
-        # Turn off punctuation if the speaker allows us to do so.  We
-        # do this because we want to handle spoken punctuation on our
-        # own.
+        # Turn off punctuation.  We do this because we want to handle
+        # spoken punctuation on our own.  Only do so if "punctuation mode" 
+        # is available (see # bug #528797).
         #
         try:
-            speaker.setParameterValue("punctuation mode", 0.0)
+            parameters = speaker.getSupportedParameters()
+            for parameter in parameters:
+                if parameter.name == "punctuation mode":
+                    speaker.setParameterValue("punctuation mode", 0.0)
+                    break
         except:
             pass
 
