@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3445 2008-01-11 17:05:52Z wwalker $"
-__version__   = "$Revision: 3445 $"
-__date__      = "$Date: 2008-01-11 12:05:52 -0500 (Fri, 11 Jan 2008) $"
+__id__        = "$Id: settings.py 3963 2008-06-05 18:10:20Z wwalker $"
+__version__   = "$Revision: 3963 $"
+__date__      = "$Date: 2008-06-05 14:10:20 -0400 (Thu, 05 Jun 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -155,7 +155,9 @@ userCustomizableSettings = [
     "enabledBrailledTextAttributes",
     "textAttributesBrailleIndicator",
     "enableProgressBarUpdates",
-    "progressBarUpdateInterval"
+    "progressBarUpdateInterval",
+    "enableContractedBraille",
+    "brailleContractionTable"
 ]
 
 # The name of the module that hold the user interface for the main window
@@ -679,6 +681,14 @@ useBonoboMain           = True
 #
 asyncMode               = True
 
+# A list of toolkits whose events we need to process synchronously.
+# The only one right now is the Java toolkit (see bug #531869), but
+# we put this here to allow more toolkits to be more easily added
+# and for Java to be removed if issues with asynchronous processing
+# of its events are ever resolved.
+#
+synchronousToolkits     = ["J2SE-access-bridge"]
+
 # If True, we output debug information for the event queue.  We
 # use this in addition to log level to prevent debug logic from
 # bogging down event handling.
@@ -899,3 +909,21 @@ listenAllEvents = False
 # This is a list of events that Orca should immidiately drop and never look at.
 #
 ignoredEventsList = ['object:bounds-changed']
+
+# Listen to Live Region events.  Tells Gecko.onChildrenChanged() and 
+# onTextInserted() event handlers to monitor these events for live region
+# changes.  
+#
+inferLiveRegions = True
+
+# Contracted braille support.
+# 
+enableContractedBraille = False
+
+# Contracted braille table.
+# 
+brailleContractionTable = ''
+
+# Use Collection Interface?
+# 
+useCollection = True
