@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 3600 2008-02-19 02:05:06Z joanied $"
-__version__   = "$Revision: 3600 $"
-__date__      = "$Date: 2008-02-18 21:05:06 -0500 (Mon, 18 Feb 2008) $"
+__id__        = "$Id: where_am_I.py 3870 2008-04-30 19:33:50Z joanied $"
+__version__   = "$Revision: 3870 $"
+__date__      = "$Date: 2008-04-30 15:33:50 -0400 (Wed, 30 Apr 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -127,7 +127,10 @@ class WhereAmI:
         elif role == pyatspi.ROLE_LIST_ITEM:
             self._speakListItem(obj, basicOnly)
 
-        elif role == pyatspi.ROLE_PARAGRAPH:
+        elif role in [pyatspi.ROLE_PARAGRAPH,
+                      pyatspi.ROLE_SECTION,
+                      pyatspi.ROLE_HEADING,
+                      pyatspi.ROLE_DOCUMENT_FRAME]:
             self._speakParagraph(obj, basicOnly)
 
         elif role == pyatspi.ROLE_ICON:
@@ -745,8 +748,9 @@ class WhereAmI:
         if link_uri:
             link_uri_info = urlparse.urlparse(link_uri)
         else:
-            # something is wrong, just return
-            return
+            # It might be an anchor.  Try to speak the text.
+            #
+            return self._speakText(obj, basicOnly)
       
         # Try to get the URI of the active document and parse it
         doc_uri = self._script.getDocumentFrameURI()
